using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel; //for Designer Attributes

namespace InsideAspNetP2CustomControls
{
	/// <summary>
	/// A stupid composite control that makes a textbox and a label mirror each other when the Text property is set
	/// </summary>
	/// <remarks>
	/// Note INamingContainer Marker Interface
	/// </remarks>
	public class SimpleCompositeControl : Control, INamingContainer
	{
		private TextBox textBoxMain;
		private Label labelShadow;

		//This method will be called by the Framework, you create & setup your child controls here
		//note the LiteralControl
		protected override void CreateChildControls()
		{
			textBoxMain = new TextBox();
			textBoxMain.ID = "textBoxMain";
			textBoxMain.Text = Text;
			textBoxMain.Columns=50;

			labelShadow = new Label();
			labelShadow.Text = textBoxMain.Text;

			Controls.Add(textBoxMain);
			Controls.Add(new LiteralControl(" = "));
			Controls.Add(labelShadow);
		}

		//Make Sure the Controls collection exists whenever it's read!
		public override ControlCollection Controls 
		{
			get 
			{
				EnsureChildControls();
				return base.Controls;
			}
		}


		#region Text property
		[
		Bindable(true),
		Category("Appearance"),
		DefaultValue(""),
		Description("The text shown within the control")
		]
		public string Text 
		{
			get 
			{
				string s = (string)ViewState["Text"];
				if (s == null) 
				{
					return String.Empty;
				}
				return s;
			}
			set 
			{
				ViewState["Text"] = value;
				
				//Set the properties of the child controls if they exist
				if (textBoxMain != null) textBoxMain.Text = value;
				if (labelShadow != null) labelShadow.Text = value;
			}
		}
        #endregion
	}
}
