using System;
using System.Web.UI;

using System.Web.UI.WebControls; // for WebControl

using System.Drawing; //for Color

using System.ComponentModel; //for Designer Attributes

namespace InsideAspNetP2
{
	/// <summary>
	/// A very simple Rendered control
	/// </summary>
	public class SimpleCustomControl : Control //WebControl is better UI Specific properties
	{
		private Color myColor = Color.Red;

		public SimpleCustomControl()
		{
			//Initialize the Property Value
			ViewState["MyProperty"] = "Hello";
		}

		/// <summary>
		/// A simple string property
		/// </summary>
		/// <remarks>
		/// Note the use of attributes to inform the IDE about this Property
		///		other attributes include: Bindable, DefaultValue, Editor (custom UI for editing), etc.
		///		see documentation for more details
		///		
		///		This Property is sticky like real MSFT controls (persists against viewstate)
		/// </remarks>
		[Description("A message string to display to the user with the time.")]
		[Category("Behavior")] 
		public string MyProperty
		{
			get	{ return (string)ViewState["MyProperty"]; }
			set	{ ViewState["MyProperty"] = value; }
		}

		/// <summary>
		/// Note how the IDE automatically knows what to do with this property because of it's type
		/// This property does not persist against viewstate so it's reset to it's original value each time
		/// from either the default of Red or whatever's in the HTML of the page which hosts it
		/// </summary>
		public System.Drawing.Color MyColor
		{
			get { return myColor; }
			set { myColor = value; } //note should have good error handling here!
		}

		protected override void Render(HtmlTextWriter writer)
		{
			//you could do stuff like this...
			//writer.Write("<b>" + myProperty + System.DateTime.Now.ToString() + "</b>");

			#region A Better way
				//Should really use this because:
				//Will automatically change HTML tags to reflect up/downlevel browsers
				//More Explicit Code is more readable and makes it harder to forget a closing tag
				//Will automatically ensure that HTML tags are consistently CASED
				//More Efficient than multiple writer.Write calls

				writer.RenderBeginTag(HtmlTextWriterTag.B);
					writer.AddAttribute("color",myColor.Name);
					writer.RenderBeginTag(HtmlTextWriterTag.Font);
						writer.Write(MyProperty + System.DateTime.Now.ToString());
					writer.RenderEndTag();
				writer.RenderEndTag();
			#endregion
		}
	}
}
