using System;
using System.Collections;
using System.Diagnostics;

using System.Web;

namespace InsideAspNetP2
{
	/// <summary>
	/// A Very Simple HttpHandler
	/// </summary>
	public class MyModule : IHttpModule
	{
		/// <summary>
		/// Delegate for BeginRequest of Application
		/// </summary>
		public delegate void MyEventHandler(Object s, EventArgs e);

		/// <summary>
		/// Holds a Reference to the Event
		/// </summary>
		private MyEventHandler _eventHandler = null;

		/// <summary>
		/// Allows Runtime to Hook this Module
		/// </summary>
		public event MyEventHandler MyEvent
		{
			add { _eventHandler += value; }
			remove { _eventHandler -= value; }
		}

		#region Implementation of IHttpModule
		public void Init(System.Web.HttpApplication context)
		{
			context.BeginRequest += new EventHandler(OnBeginRequest);
		}
		
		public void Dispose()
		{
			//No Cleanup Necessary here, but must have an empty implementation for the Interface
		}
	
		#endregion

		/// <summary>
		/// Hooked to BeginRequest of the Application see Init()
		/// </summary>
		/// <param name="s"></param>
		/// <param name="e"></param>
		public void OnBeginRequest(Object s, EventArgs e)
		{
			HttpApplication app = s as HttpApplication;
			
			app.Context.Response.Write("Hello from OnBeginRequest in custom module.<br>");
			
			if(_eventHandler!=null)
				_eventHandler(this, null);
		}

	} // Class MyHandler
} //Namespace
